==================================
 (one line goal description here)
==================================

Explain what the goal is in general terms. Include the reasoning and
justification for applying the goal to all OpenStack projects.

:Storyboard Board: <put the link to the tracking board here>
:Storyboard Story: <put the link to the story for this goal here>

Champion
========

Goals need a main driver to project-manage them to completion. Project teams
need assistance, reminders and sometimes direct help in order for them to
complete the goals.

Gerrit Topic
============

To facilitate tracking, commits related to this goal should use the
gerrit topic::

  <insert topic here>

Completion Criteria
===================

Enumerate the items that must be true in order to call the goal
"completed" for a given project.

#. one
#. two

References
==========

Provide reference links to previous discussions on the mailing list or
IRC, etherpads, wiki pages, other forms of notes, and documentation
that would be useful to a project team in working on the goal.

Current State / Anticipated Impact
==================================

Provide a summary of the current state of any ongoing work related to
the goal, including known blockers for any projects, projects that
have completed the work already and can serve as examples, or other
information useful to evaluate the scope of the goal and whether it
would fit into the time given.
